/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbstractMBeanOperation.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.jmx.impl;

import javax.management.MBeanOperationInfo;
import javax.management.MBeanParameterInfo;

import org.ow2.util.jmx.api.IMBeanOperation;

/**
 * Implementations of this class can be added dynamically as operations in a BaseModelMBeanExt.
 * @author missonng
 */
public abstract class AbstractMBeanOperation implements IMBeanOperation {
    /**
     * The MBeanOperationInfo describing this operation.
     */
    private MBeanOperationInfo info;

    /**
     * The AbstractMBeanOperation constructor.
     * @param name The name of the method.
     * @param description A human readable description of the operation.
     * @param params MBeanParameterInfo objects describing the parameters(arguments) of the method.
     * This may be null with the same effect as a zero-length array.
     * @param type The type of the method's return value.
     * @param impact The impact of the method, one of INFO, ACTION, ACTION_INFO, UNKNOWN.
     */
    public AbstractMBeanOperation(final String name, final String description, final MBeanParameterInfo[] params,
            final String type, final int impact) {
        this.info = new MBeanOperationInfo(name, description, params, type, impact);
    }

    /**
     * Get the MBeanOperationInfo describing this operation.
     * @return The MBeanOperationInfo describing this operation.
     */
    public MBeanOperationInfo getMBeanOperationInfo() {
        return this.info;
    }
}
